==> dataspex-2025.06.6.jar: public/app/cljs-runtime/dataspex.dev.js <==
goog.provide('dataspex.dev');
if((typeof dataspex !== 'undefined') && (typeof dataspex.dev !== 'undefined') && (typeof dataspex.dev.store !== 'undefined')){
} else {
dataspex.dev.store = cljs.core.atom.cljs$core$IFn$_invoke$arity$1(cljs.core.PersistentArrayMap.EMPTY);
}
dataspex.data.add_string_inspector_BANG_(dataspex.jwt.inspect_jwt);
if((typeof dataspex !== 'undefined') && (typeof dataspex.dev !== 'undefined') && (typeof dataspex.dev.txes !== 'undefined')){
} else {
dataspex.dev.txes = dataspex.demo_data.add_data(dataspex.demo_data.conn);
}
dataspex.dev.client = dataspex.render_client.start_render_client(document.body,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"handle-remotes-actions","handle-remotes-actions",1745680369),dataspex.remotes_panel.handle_actions,new cljs.core.Keyword(null,"render-remotes","render-remotes",1109529878),dataspex.remotes_panel.render_panel], null));
dataspex.render_client.add_channel(dataspex.dev.client,"process",dataspex.in_process_client.create_channel(dataspex.dev.store));
dataspex.dev.main = (function dataspex$dev$main(){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(dataspex.dev.store,cljs.core.assoc,new cljs.core.Keyword("dataspex.dev","loaded","dataspex.dev/loaded",-564032022),(new Date()).getTime());
});
if((typeof dataspex !== 'undefined') && (typeof dataspex.dev !== 'undefined') && (typeof dataspex.dev.app_store !== 'undefined')){
} else {
dataspex.dev.app_store = cljs.core.atom.cljs$core$IFn$_invoke$arity$1(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"loading?","loading?",1905707049),true], null));
}
setTimeout((function (){
return cljs.core.reset_BANG_(dataspex.dev.app_store,dataspex.demo_state.app_state);
}),(2500));
dataspex.core.inspect.cljs$core$IFn$_invoke$arity$variadic("App state",dataspex.dev.app_store,cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("dataspex","ns-aliases","dataspex/ns-aliases",-650199969),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Symbol(null,"really.long.ns","really.long.ns",-861404117,null),new cljs.core.Symbol(null,"rl","rl",1709558636,null)], null)], null)], 0));
document.body.addEventListener("click",(function (e){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(dataspex.dev.app_store,cljs.core.assoc,new cljs.core.Keyword(null,"event","event",301435442),e);
}));

//# sourceMappingURL=dataspex.dev.js.map

==> dataspex-2026.01.1.jar: public/app/cljs-runtime/dataspex.dev.js <==
goog.provide('dataspex.dev');
if((typeof dataspex !== 'undefined') && (typeof dataspex.dev !== 'undefined') && (typeof dataspex.dev.store !== 'undefined')){
} else {
dataspex.dev.store = cljs.core.atom.cljs$core$IFn$_invoke$arity$1(cljs.core.PersistentArrayMap.EMPTY);
}
dataspex.data.add_string_inspector_BANG_(dataspex.jwt.inspect_jwt);
dataspex.dev.client = dataspex.render_client.start_render_client(document.body,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"handle-remotes-actions","handle-remotes-actions",1745680369),dataspex.remotes_panel.handle_actions,new cljs.core.Keyword(null,"render-remotes","render-remotes",1109529878),dataspex.remotes_panel.render_panel], null));
dataspex.render_client.add_channel(dataspex.dev.client,"process",dataspex.in_process_client.create_channel(dataspex.dev.store));
dataspex.dev.main = (function dataspex$dev$main(){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(dataspex.dev.store,cljs.core.assoc,new cljs.core.Keyword("dataspex.dev","loaded","dataspex.dev/loaded",-564032022),(new Date()).getTime());
});
dataspex.inspector.inspect(dataspex.dev.store,"DB",dataspex.demo_data.conn);
if((typeof dataspex !== 'undefined') && (typeof dataspex.dev !== 'undefined') && (typeof dataspex.dev.txes !== 'undefined')){
} else {
dataspex.dev.txes = dataspex.demo_data.add_data(dataspex.demo_data.conn);
}
dataspex.inspector.inspect.cljs$core$IFn$_invoke$arity$variadic(dataspex.dev.store,"Hiccup",dataspex.panel.render_panel(cljs.core.deref(dataspex.dev.store),"App state"),cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"default-hiccup-folding-level","default-hiccup-folding-level",-713055521),(5)], null)], 0));

//# sourceMappingURL=dataspex.dev.js.map
